@@ -3,7 +3,6 @@ import os.path
 import subprocess
 from pathlib import Path
 import inspect
-
 import pytest
 
 
@@ -46,7 +45,8 @@ def with_import(module_name=None, function_name=None):
         nonlocal function_name
         nonlocal module_name
         params = inspect.signature(test_function).parameters
-        function_name = function_name or next((pname for pname, _ in params.items()))
+        first_param = next((pname for pname, _ in params.items()))
+        function_name = function_name or first_param
         module_name = module_name or function_name
 
         def new_test_function(*args, **kwargs):
@@ -73,14 +73,13 @@ def with_import(module_name=None, function_name=None):
                     f'Unable to load {function_name} from {module_name}.py. '
                     f'Is {function_name} defined?'
                 )
-            except AssertionError as err:
-                pass
-            except Exception as ex:
-                pytest.fail(
-                    f'{type(ex).__name__}: {ex}\n'
-                    f'Something unexpected went wrong while importing {function_name} from {module_name}.py. '
-                    f'Please inform the course instructor of this error.'
-                )
+
+        # Modify signature to look like test_function but without
+        # anything filled by with_import
+        sig = inspect.signature(test_function)
+        sig._parameters = dict(sig.parameters)
+        del sig._parameters[first_param]
+        new_test_function.__signature__ = sig
 
         return new_test_function
 
